RDF Loom
=============================
RDF Loom is a library of python functions that can be utilized to create RDF graphs from tabular data. 
Future versions will also include functions to create RDF from other data formats, such as JSON, YAML and XML
